@@ -1,5 +1,9 @@
 package Test1::Step::CombineFiles;
 
+use strict;
+use warnings;
+use namespace::autoclean;
+
 use Stepford::Types qw( Dir File );
 
 use Moose;
@@ -31,24 +35,27 @@ has combined_file => (
     is      => 'ro',
     isa     => File,
     lazy    => 1,
-    default => sub { $_[0]->tempdir()->file('combined') },
+    default => sub { $_[0]->tempdir->file('combined') },
 );
 
+## no critic (Variables::ProhibitPackageVars)
 our $RunCount = 0;
 
 sub run {
     my $self = shift;
 
-    $self->combined_file()->spew(
+    $self->combined_file->spew(
         [
-            map { $_->slurp() } $self->a1_file_updated(),
-            $self->a2_file_updated()
+            map { $_->slurp } $self->a1_file_updated,
+            $self->a2_file_updated
         ]
     );
 }
 
 after run => sub { $RunCount++ };
 
-__PACKAGE__->meta()->make_immutable();
+sub run_count { $RunCount }
+
+__PACKAGE__->meta->make_immutable;
 
 1;
